-- replacement love.run

function love.run()
	math.randomseed( os.time() )
	math.random() math.random()
	love.draw_clear = true		-- insures that screen is cleared each frame
	if love.load then love.load(arg) end	-- command line parameter entry
	local dt = 0
	-- Main loop time.
	while true do
		------------
		-- events --
		------------
		if love.event then
			love.event.pump()
			for e,a,b,c,d in love.event.poll() do
				if e == "quit" then
					if not love.quit or not love.quit() then
						if love.audio then love.audio.stop() end
						return
						end
					end
				love.handlers[e](a,b,c,d)
				end
			end
		-------------------------
		-- create dt parameter --
		-------------------------
		if love.timer then
			love.timer.step()
			dt = love.timer.getDelta()
			end
		---------------------------------------------
		-- determine if fixed frame rate requested --
		---------------------------------------------
		if love.fixed_fps then love.fixed_loop_time(love.dt) end
		----------------------------
		-- check for draw request --
		----------------------------
		if love.graphics then
			if love.draw_clear then love.graphics.clear() end
			if love.draw then love.draw() end
			love.graphics.present()
			end
		------------------------------
		-- check for update request --
		------------------------------
		if love.update then love.update(dt) end -- will pass 0 if love.timer is disabled
		end
	end

function love.Enable( request, val )
	-----------------------------
	-- enable special features --
	-----------------------------
	if request == 'fps' then 	-- fixed loop time
		-- (differs from 'love.timer.sleep' which only adds time to each frame)
		local val 		= val or 10
		love.fixed_fps	= true
		love.dt			= 1 / val	-- convert fps to msec
		love.startTime	= os.clock()
		end
	if request == 'draw_clear' then love.draw_clear = true end
	end

function love.fixed_loop_time( dur )	-- provide fixed fps == 1000 / sec
	-------------------------------------------------------------
	-- provide additional time to maintain constant frame rate --
	-------------------------------------------------------------
	local currentTime	= os.clock()
	local deltaTime		= currentTime - love.startTime
	while deltaTime 	<= dur do
		currentTime 	= os.clock()
		deltaTime 		= currentTime - love.startTime
		end
	love.startTime 		= currentTime
	end

function love.Disable( request )
	---------------------------------------------------
	-- disable special features previously requested --
	---------------------------------------------------
	if request == "draw_clear"	then love.draw_clear	= false	end
	if request == "fps"			then love.fixed_fps		= false	end
	end

